==> istio-model-v1beta1-6.6.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl<A extends LoadBalancerSettingsConsistentHashLBHttpCookieFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashLBHttpCookieFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl(LoadBalancerSettingsConsistentHashLBHttpCookie instance) {
    this.withHttpCookie(instance.getHttpCookie()); 
  }
  private LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder httpCookie;
  
  /**
   * This method has been deprecated, please use method buildHttpCookie instead.
   * @return The buildable object.
   */
  @Deprecated
  public LoadBalancerSettingsConsistentHashLBHttpCookieValue getHttpCookie() {
    return this.httpCookie!=null ?this.httpCookie.build():null;
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValue buildHttpCookie() {
    return this.httpCookie!=null ?this.httpCookie.build():null;
  }
  public A withHttpCookie(LoadBalancerSettingsConsistentHashLBHttpCookieValue httpCookie) {
    _visitables.get("httpCookie").remove(this.httpCookie);
    if (httpCookie!=null){ this.httpCookie= new LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(httpCookie); _visitables.get("httpCookie").add(this.httpCookie);} else { this.httpCookie = null; _visitables.get("httpCookie").remove(this.httpCookie); } return (A) this;
  }
  public Boolean hasHttpCookie() {
    return this.httpCookie != null;
  }
  public A withNewHttpCookie(String name,String path,String ttl) {
    return (A)withHttpCookie(new LoadBalancerSettingsConsistentHashLBHttpCookieValue(name, path, ttl));
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluent.HttpCookieNested<A> withNewHttpCookie() {
    return new LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNestedImpl();
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluent.HttpCookieNested<A> withNewHttpCookieLike(LoadBalancerSettingsConsistentHashLBHttpCookieValue item) {
    return new LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNestedImpl(item);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluent.HttpCookieNested<A> editHttpCookie() {
    return withNewHttpCookieLike(getHttpCookie());
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluent.HttpCookieNested<A> editOrNewHttpCookie() {
    return withNewHttpCookieLike(getHttpCookie() != null ? getHttpCookie(): new LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder().build());
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluent.HttpCookieNested<A> editOrNewHttpCookieLike(LoadBalancerSettingsConsistentHashLBHttpCookieValue item) {
    return withNewHttpCookieLike(getHttpCookie() != null ? getHttpCookie(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl that = (LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl) o;
    if (httpCookie != null ? !httpCookie.equals(that.httpCookie) :that.httpCookie != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpCookie,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpCookie != null) { sb.append("httpCookie:"); sb.append(httpCookie); }
    sb.append("}");
    return sb.toString();
  }
  class HttpCookieNestedImpl<N> extends LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl<LoadBalancerSettingsConsistentHashLBHttpCookieFluent.HttpCookieNested<N>> implements LoadBalancerSettingsConsistentHashLBHttpCookieFluent.HttpCookieNested<N>,Nested<N>{
    HttpCookieNestedImpl(LoadBalancerSettingsConsistentHashLBHttpCookieValue item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(this, item);
    }
    HttpCookieNestedImpl() {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(this);
    }
    LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.this.withHttpCookie(builder.build());
    }
    public N endHttpCookie() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl<A extends LoadBalancerSettingsConsistentHashLBHttpCookieFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashLBHttpCookieFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl(LoadBalancerSettingsConsistentHashLBHttpCookie instance) {
    if (instance != null) {
      this.withHttpCookie(instance.getHttpCookie());
    }
  }
  private LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder httpCookie;
  
  /**
   * This method has been deprecated, please use method buildHttpCookie instead.
   * @return The buildable object.
   */
  @Deprecated
  public LoadBalancerSettingsConsistentHashLBHttpCookieValue getHttpCookie() {
    return this.httpCookie!=null ?this.httpCookie.build():null;
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieValue buildHttpCookie() {
    return this.httpCookie!=null ?this.httpCookie.build():null;
  }
  public A withHttpCookie(LoadBalancerSettingsConsistentHashLBHttpCookieValue httpCookie) {
    _visitables.get("httpCookie").remove(this.httpCookie);
    if (httpCookie!=null){ this.httpCookie= new LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(httpCookie); _visitables.get("httpCookie").add(this.httpCookie);} else { this.httpCookie = null; _visitables.get("httpCookie").remove(this.httpCookie); } return (A) this;
  }
  public Boolean hasHttpCookie() {
    return this.httpCookie != null;
  }
  public A withNewHttpCookie(String name,String path,String ttl) {
    return (A)withHttpCookie(new LoadBalancerSettingsConsistentHashLBHttpCookieValue(name, path, ttl));
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNested<A> withNewHttpCookie() {
    return new LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNestedImpl();
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNested<A> withNewHttpCookieLike(LoadBalancerSettingsConsistentHashLBHttpCookieValue item) {
    return new LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNestedImpl(item);
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNested<A> editHttpCookie() {
    return withNewHttpCookieLike(getHttpCookie());
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNested<A> editOrNewHttpCookie() {
    return withNewHttpCookieLike(getHttpCookie() != null ? getHttpCookie(): new LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder().build());
  }
  public LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNested<A> editOrNewHttpCookieLike(LoadBalancerSettingsConsistentHashLBHttpCookieValue item) {
    return withNewHttpCookieLike(getHttpCookie() != null ? getHttpCookie(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl that = (LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl) o;
    if (!java.util.Objects.equals(httpCookie, that.httpCookie)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpCookie,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpCookie != null) { sb.append("httpCookie:"); sb.append(httpCookie); }
    sb.append("}");
    return sb.toString();
  }
  class HttpCookieNestedImpl<N> extends LoadBalancerSettingsConsistentHashLBHttpCookieValueFluentImpl<LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNested<N>> implements LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.HttpCookieNested<N>,Nested<N>{
    HttpCookieNestedImpl(LoadBalancerSettingsConsistentHashLBHttpCookieValue item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(this, item);
    }
    HttpCookieNestedImpl() {
      this.builder = new LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder(this);
    }
    LoadBalancerSettingsConsistentHashLBHttpCookieValueBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashLBHttpCookieFluentImpl.this.withHttpCookie(builder.build());
    }
    public N endHttpCookie() {
      return and();
    }
    
  }
  
}
